package com.isulnara.demo;

import android.app.Activity;
import android.content.Intent;
import android.os.Bundle;
import android.util.Log;

public class SplashDemoActivity extends Activity
{
	@Override
	public void onCreate(Bundle savedInstanceState)
	{
		// 스플래시 화면 띄우기
		startActivity(new Intent(this, SplashActivity.class));

		super.onCreate(savedInstanceState);
		setContentView(R.layout.main);

        // 여기부터 시간이 걸리는 작업 처리
        //initializeBad();	// 좋지않은 초기화
        initializeGood();	// 좋은(??) 초기화
	}


	/**
	 * 좋지않은 초기화
	 *
	 * - 아래 코드는 5초 동안 지연시키는 기능을 합니다.
	 * - 이런 방법으로 처리하면 스플래시 화면이 5초 후에 표시됩니다.
	 */
	private void initializeBad()
	{
		for (int i=0; i<5;i++)
		{
			try
			{
				Thread.sleep(1000);
			}
			catch (InterruptedException e)
			{
				e.printStackTrace();
			}
		}
	}


	/**
	 * 좋은(??) 초기화
	 *
	 * - 스플래시 화면이 표시되는 동안에 어떤 일(예를 들면 초기화  작업)을 시키려면 작업을 메인쓰레드가 아닌 다른 쓰레드에서 처리하도록 해야됩니다.
	 * - 메인 쓰레드는 스플래시 화면을 표시하는 일을 해야 되니까요.. 메인 쓰레드 혼자서 작업 2개를 동시에 할 수는 없습니다.
	 */
	private void initializeGood()
	{
		InitializationRunnable init = new InitializationRunnable();
		new Thread(init).start();
	}



	/**
	 * 초기화 작업 처리
	 *
	 */
	class InitializationRunnable implements Runnable
	{
	    public void run()
	    {
	    	// 여기서부터 초기화 작업 처리
			for (int i=0; i<5;i++)
			{
				try
				{
					Thread.sleep(1000);

					// LogCat으로 로그를 보면 스플래시 화면 표시 중에 계속 이미 메시지가 표시됨을 확인할 수 있습니다.
					Log.d("SPLASH", "------------- initialize..........");
				}
				catch (InterruptedException e)
				{
					e.printStackTrace();
				}
			}
	    }
	}
}